@@ -549,7 +549,7 @@ NumericVector ths_h00(NumericMatrix x, NumericVector t, NumericVector theta,
   double sigma = theta[3], p = theta[4];
 
   /* set up for Rdqags */
-  double *ex = Calloc(7 + dim, double);
+  double *ex = R_Calloc(7 + dim, double);
   double a = 0., b; // = t;
   // input
   double epsabs = integrControl[0], epsrel = integrControl[1];
@@ -559,8 +559,8 @@ NumericVector ths_h00(NumericMatrix x, NumericVector t, NumericVector theta,
   int last, ier;  // integrate()$subdivision and integrate()$message
   int neval; // number of evaluation of integrand
   // working arrays
-  int lenw = 4 * limit, *iwork = Calloc(limit, int);
-  double *work = Calloc(lenw,  double);
+  int lenw = 4 * limit, *iwork = R_Calloc(limit, int);
+  double *work = R_Calloc(lenw,  double);
   /* done setting for Rdqags */
 
   ex[1] = sigma; ex[2] = lambda0; ex[3] = lambda1; ex[4] = lambda2;
@@ -581,7 +581,7 @@ NumericVector ths_h00(NumericMatrix x, NumericVector t, NumericVector theta,
     value[i] = result + prod;
   }
   // free memory
-  Free(ex); Free(iwork); Free(work);
+  R_Free(ex); R_Free(iwork); R_Free(work);
   return(value);
 }
 
@@ -594,7 +594,7 @@ NumericVector ths_h01(NumericMatrix x, NumericVector t, NumericVector theta,
   double sigma = theta[3], p = theta[4];
 
   /* set up for Rdqags */
-  double *ex = Calloc(7 + dim, double);
+  double *ex = R_Calloc(7 + dim, double);
   double a = 0., b; // = t;
   // input
   double epsabs = integrControl[0], epsrel = integrControl[1];
@@ -604,8 +604,8 @@ NumericVector ths_h01(NumericMatrix x, NumericVector t, NumericVector theta,
   int last, ier;  // integrate()$subdivision and integrate()$message
   int neval; // number of evaluation of integrand
   // working arrays
-  int lenw = 4 * limit, *iwork = Calloc(limit, int);
-  double *work = Calloc(lenw,  double);
+  int lenw = 4 * limit, *iwork = R_Calloc(limit, int);
+  double *work = R_Calloc(lenw,  double);
   /* done setting for Rdqags */
 
   ex[1] = sigma; ex[2] = lambda0; ex[3] = lambda1; ex[4] = lambda2;
@@ -620,7 +620,7 @@ NumericVector ths_h01(NumericMatrix x, NumericVector t, NumericVector theta,
     value[i] = result;
   }
   // free memory
-  Free(ex); Free(iwork); Free(work);
+  R_Free(ex); R_Free(iwork); R_Free(work);
   return(value);
 }
 
@@ -632,7 +632,7 @@ NumericVector ths_h02(NumericMatrix x, NumericVector t, NumericVector theta,
   double sigma = theta[3], p = theta[4];
 
   /* set up for Rdqags */
-  double *ex = Calloc(7 + dim, double);
+  double *ex = R_Calloc(7 + dim, double);
   double a = 0., b; // = t;
   // input
   double epsabs = integrControl[0], epsrel = integrControl[1];
@@ -642,8 +642,8 @@ NumericVector ths_h02(NumericMatrix x, NumericVector t, NumericVector theta,
   int last, ier;  // integrate()$subdivision and integrate()$message
   int neval; // number of evaluation of integrand
   // working arrays
-  int lenw = 4 * limit, *iwork = Calloc(limit, int);
-  double *work = Calloc(lenw,  double);
+  int lenw = 4 * limit, *iwork = R_Calloc(limit, int);
+  double *work = R_Calloc(lenw,  double);
   /* done setting for Rdqags */
 
   ex[1] = sigma; ex[2] = lambda0; ex[3] = lambda1; ex[4] = lambda2;
@@ -658,7 +658,7 @@ NumericVector ths_h02(NumericMatrix x, NumericVector t, NumericVector theta,
     value[i] = result;
   }
   // free memory
-  Free(ex); Free(iwork); Free(work);
+  R_Free(ex); R_Free(iwork); R_Free(work);
   return(value);
 }
 
@@ -671,7 +671,7 @@ NumericVector ths_h10(NumericMatrix x, NumericVector t, NumericVector theta,
   double sigma = theta[3], p = theta[4];
 
   /* set up for Rdqags */
-  double *ex = Calloc(7 + dim, double);
+  double *ex = R_Calloc(7 + dim, double);
   double a = 0., b; // = t;
   // input
   double epsabs = integrControl[0], epsrel = integrControl[1];
@@ -681,8 +681,8 @@ NumericVector ths_h10(NumericMatrix x, NumericVector t, NumericVector theta,
   int last, ier;  // integrate()$subdivision and integrate()$message
   int neval; // number of evaluation of integrand
   // working arrays
-  int lenw = 4 * limit, *iwork = Calloc(limit, int);
-  double *work = Calloc(lenw,  double);
+  int lenw = 4 * limit, *iwork = R_Calloc(limit, int);
+  double *work = R_Calloc(lenw,  double);
   /* done setting for Rdqags */
 
   ex[1] = sigma; ex[2] = lambda0; ex[3] = lambda1; ex[4] = lambda2;
@@ -697,7 +697,7 @@ NumericVector ths_h10(NumericMatrix x, NumericVector t, NumericVector theta,
     value[i] = result;
   }
   // free memory
-  Free(ex); Free(iwork); Free(work);
+  R_Free(ex); R_Free(iwork); R_Free(work);
   return(value);
 }
 
@@ -709,7 +709,7 @@ NumericVector ths_h11(NumericMatrix x, NumericVector t, NumericVector theta,
   double sigma = theta[3], p = theta[4];
 
   /* set up for Rdqags */
-  double *ex = Calloc(7 + dim, double);
+  double *ex = R_Calloc(7 + dim, double);
   double a = 0., b; // = t;
   // input
   double epsabs = integrControl[0], epsrel = integrControl[1];
@@ -719,8 +719,8 @@ NumericVector ths_h11(NumericMatrix x, NumericVector t, NumericVector theta,
   int last, ier;  // integrate()$subdivision and integrate()$message
   int neval; // number of evaluation of integrand
   // working arrays
-  int lenw = 4 * limit, *iwork = Calloc(limit, int);
-  double *work = Calloc(lenw,  double);
+  int lenw = 4 * limit, *iwork = R_Calloc(limit, int);
+  double *work = R_Calloc(lenw,  double);
   /* done setting for Rdqags */
 
   ex[1] = sigma; ex[2] = lambda0; ex[3] = lambda1; ex[4] = lambda2;
@@ -735,7 +735,7 @@ NumericVector ths_h11(NumericMatrix x, NumericVector t, NumericVector theta,
     value[i] = result;
   }
   // free memory
-  Free(ex); Free(iwork); Free(work);
+  R_Free(ex); R_Free(iwork); R_Free(work);
   return(value);
 }
 
@@ -747,7 +747,7 @@ NumericVector ths_h12(NumericMatrix x, NumericVector t, NumericVector theta,
   double sigma = theta[3], p = theta[4];
 
   /* set up for Rdqags */
-  double *ex = Calloc(7 + dim, double);
+  double *ex = R_Calloc(7 + dim, double);
   double a = 0., b; // = t;
   // input
   double epsabs = integrControl[0], epsrel = integrControl[1];
@@ -757,8 +757,8 @@ NumericVector ths_h12(NumericMatrix x, NumericVector t, NumericVector theta,
   int last, ier;  // integrate()$subdivision and integrate()$message
   int neval; // number of evaluation of integrand
   // working arrays
-  int lenw = 4 * limit, *iwork = Calloc(limit, int);
-  double *work = Calloc(lenw,  double);
+  int lenw = 4 * limit, *iwork = R_Calloc(limit, int);
+  double *work = R_Calloc(lenw,  double);
   /* done setting for Rdqags */
 
   ex[1] = sigma; ex[2] = lambda0; ex[3] = lambda1; ex[4] = lambda2;
@@ -773,7 +773,7 @@ NumericVector ths_h12(NumericMatrix x, NumericVector t, NumericVector theta,
     value[i] = result;
   }
   // free memory
-  Free(ex); Free(iwork); Free(work);
+  R_Free(ex); R_Free(iwork); R_Free(work);
   return(value);
 }
 
@@ -785,7 +785,7 @@ NumericVector ths_h20(NumericMatrix x, NumericVector t, NumericVector theta,
   double sigma = theta[3], p = theta[4];
 
   /* set up for Rdqags */
-  double *ex = Calloc(7 + dim, double);
+  double *ex = R_Calloc(7 + dim, double);
   double a = 0., b; // = t;
   // input
   double epsabs = integrControl[0], epsrel = integrControl[1];
@@ -795,8 +795,8 @@ NumericVector ths_h20(NumericMatrix x, NumericVector t, NumericVector theta,
   int last, ier;  // integrate()$subdivision and integrate()$message
   int neval; // number of evaluation of integrand
   // working arrays
-  int lenw = 4 * limit, *iwork = Calloc(limit, int);
-  double *work = Calloc(lenw,  double);
+  int lenw = 4 * limit, *iwork = R_Calloc(limit, int);
+  double *work = R_Calloc(lenw,  double);
   /* done setting for Rdqags */
 
   ex[1] = sigma; ex[2] = lambda0; ex[3] = lambda1; ex[4] = lambda2;
@@ -811,7 +811,7 @@ NumericVector ths_h20(NumericMatrix x, NumericVector t, NumericVector theta,
     value[i] = result;
   }
   // free memory
-  Free(ex); Free(iwork); Free(work);
+  R_Free(ex); R_Free(iwork); R_Free(work);
   return(value);
 }
 
@@ -823,7 +823,7 @@ NumericVector ths_h21(NumericMatrix x, NumericVector t, NumericVector theta,
   double sigma = theta[3], p = theta[4];
 
   /* set up for Rdqags */
-  double *ex = Calloc(7 + dim, double);
+  double *ex = R_Calloc(7 + dim, double);
   double a = 0., b; // = t;
   // input
   double epsabs = integrControl[0], epsrel = integrControl[1];
@@ -833,8 +833,8 @@ NumericVector ths_h21(NumericMatrix x, NumericVector t, NumericVector theta,
   int last, ier;  // integrate()$subdivision and integrate()$message
   int neval; // number of evaluation of integrand
   // working arrays
-  int lenw = 4 * limit, *iwork = Calloc(limit, int);
-  double *work = Calloc(lenw,  double);
+  int lenw = 4 * limit, *iwork = R_Calloc(limit, int);
+  double *work = R_Calloc(lenw,  double);
   /* done setting for Rdqags */
 
   ex[1] = sigma; ex[2] = lambda0; ex[3] = lambda1; ex[4] = lambda2;
@@ -849,7 +849,7 @@ NumericVector ths_h21(NumericMatrix x, NumericVector t, NumericVector theta,
     value[i] = result;
   }
   // free memory
-  Free(ex); Free(iwork); Free(work);
+  R_Free(ex); R_Free(iwork); R_Free(work);
   return(value);
 }
 
@@ -862,7 +862,7 @@ NumericVector ths_h22(NumericMatrix x, NumericVector t, NumericVector theta,
   double sigma = theta[3], p = theta[4];
 
   /* set up for Rdqags */
-  double *ex = Calloc(7 + dim, double);
+  double *ex = R_Calloc(7 + dim, double);
   double a = 0., b; // = t;
   // input
   double epsabs = integrControl[0], epsrel = integrControl[1];
@@ -872,8 +872,8 @@ NumericVector ths_h22(NumericMatrix x, NumericVector t, NumericVector theta,
   int last, ier;  // integrate()$subdivision and integrate()$message
   int neval; // number of evaluation of integrand
   // working arrays
-  int lenw = 4 * limit, *iwork = Calloc(limit, int);
-  double *work = Calloc(lenw,  double);
+  int lenw = 4 * limit, *iwork = R_Calloc(limit, int);
+  double *work = R_Calloc(lenw,  double);
   /* done setting for Rdqags */
 
   ex[1] = sigma; ex[2] = lambda0; ex[3] = lambda1; ex[4] = lambda2;
@@ -888,7 +888,7 @@ NumericVector ths_h22(NumericMatrix x, NumericVector t, NumericVector theta,
     value[i] = result;
   }
   // free memory
-  Free(ex); Free(iwork); Free(work);
+  R_Free(ex); R_Free(iwork); R_Free(work);
   return(value);
 }
 
@@ -925,7 +925,7 @@ struct THS_h00_p : public Worker {
     double sigma = theta[3], p = theta[4];
 
     /* set up for Rdqags */
-    double *ex = Calloc(7 + dim, double);
+    double *ex = R_Calloc(7 + dim, double);
     double a = 0., b; // = t;
     // input
     double epsabs = integrControl[0], epsrel = integrControl[1];
@@ -935,8 +935,8 @@ struct THS_h00_p : public Worker {
     int last, ier;  // integrate()$subdivision and integrate()$message
     int neval; // number of evaluation of integrand
     // working arrays
-    int lenw = 4 * limit, *iwork = Calloc(limit, int);
-    double *work = Calloc(lenw,  double);
+    int lenw = 4 * limit, *iwork = R_Calloc(limit, int);
+    double *work = R_Calloc(lenw,  double);
     /* done setting for Rdqags */
 
     ex[1] = sigma; ex[2] = lambda0; ex[3] = lambda1; ex[4] = lambda2;
@@ -957,7 +957,7 @@ struct THS_h00_p : public Worker {
       value[i] = result + prod;
     }
   // free memory
-  Free(ex); Free(iwork); Free(work);
+  R_Free(ex); R_Free(iwork); R_Free(work);
   }
 };
 
@@ -1005,7 +1005,7 @@ struct THS_h01_p : public Worker {
     double sigma = theta[3], p = theta[4];
 
     /* set up for Rdqags */
-    double *ex = Calloc(7 + dim, double);
+    double *ex = R_Calloc(7 + dim, double);
     double a = 0., b; // = t;
     // input
     double epsabs = integrControl[0], epsrel = integrControl[1];
@@ -1015,8 +1015,8 @@ struct THS_h01_p : public Worker {
     int last, ier;  // integrate()$subdivision and integrate()$message
     int neval; // number of evaluation of integrand
     // working arrays
-    int lenw = 4 * limit, *iwork = Calloc(limit, int);
-    double *work = Calloc(lenw,  double);
+    int lenw = 4 * limit, *iwork = R_Calloc(limit, int);
+    double *work = R_Calloc(lenw,  double);
     /* done setting for Rdqags */
 
     ex[1] = sigma; ex[2] = lambda0; ex[3] = lambda1; ex[4] = lambda2;
@@ -1031,7 +1031,7 @@ struct THS_h01_p : public Worker {
       value[i] = result;
     }
   // free memory
-  Free(ex); Free(iwork); Free(work);
+  R_Free(ex); R_Free(iwork); R_Free(work);
   }
 };
 
@@ -1079,7 +1079,7 @@ struct THS_h02_p : public Worker {
     double sigma = theta[3], p = theta[4];
 
     /* set up for Rdqags */
-    double *ex = Calloc(7 + dim, double);
+    double *ex = R_Calloc(7 + dim, double);
     double a = 0., b; // = t;
     // input
     double epsabs = integrControl[0], epsrel = integrControl[1];
@@ -1089,8 +1089,8 @@ struct THS_h02_p : public Worker {
     int last, ier;  // integrate()$subdivision and integrate()$message
     int neval; // number of evaluation of integrand
     // working arrays
-    int lenw = 4 * limit, *iwork = Calloc(limit, int);
-    double *work = Calloc(lenw,  double);
+    int lenw = 4 * limit, *iwork = R_Calloc(limit, int);
+    double *work = R_Calloc(lenw,  double);
     /* done setting for Rdqags */
 
     ex[1] = sigma; ex[2] = lambda0; ex[3] = lambda1; ex[4] = lambda2;
@@ -1105,7 +1105,7 @@ struct THS_h02_p : public Worker {
       value[i] = result;
     }
   // free memory
-  Free(ex); Free(iwork); Free(work);
+  R_Free(ex); R_Free(iwork); R_Free(work);
   }
 };
 
@@ -1153,7 +1153,7 @@ struct THS_h10_p : public Worker {
     double sigma = theta[3], p = theta[4];
 
     /* set up for Rdqags */
-    double *ex = Calloc(7 + dim, double);
+    double *ex = R_Calloc(7 + dim, double);
     double a = 0., b; // = t;
     // input
     double epsabs = integrControl[0], epsrel = integrControl[1];
@@ -1163,8 +1163,8 @@ struct THS_h10_p : public Worker {
     int last, ier;  // integrate()$subdivision and integrate()$message
     int neval; // number of evaluation of integrand
     // working arrays
-    int lenw = 4 * limit, *iwork = Calloc(limit, int);
-    double *work = Calloc(lenw,  double);
+    int lenw = 4 * limit, *iwork = R_Calloc(limit, int);
+    double *work = R_Calloc(lenw,  double);
     /* done setting for Rdqags */
 
     ex[1] = sigma; ex[2] = lambda0; ex[3] = lambda1; ex[4] = lambda2;
@@ -1179,7 +1179,7 @@ struct THS_h10_p : public Worker {
       value[i] = result;
     }
   // free memory
-  Free(ex); Free(iwork); Free(work);
+  R_Free(ex); R_Free(iwork); R_Free(work);
   }
 };
 
@@ -1227,7 +1227,7 @@ struct THS_h11_p : public Worker {
     double sigma = theta[3], p = theta[4];
 
     /* set up for Rdqags */
-    double *ex = Calloc(7 + dim, double);
+    double *ex = R_Calloc(7 + dim, double);
     double a = 0., b; // = t;
     // input
     double epsabs = integrControl[0], epsrel = integrControl[1];
@@ -1237,8 +1237,8 @@ struct THS_h11_p : public Worker {
     int last, ier;  // integrate()$subdivision and integrate()$message
     int neval; // number of evaluation of integrand
     // working arrays
-    int lenw = 4 * limit, *iwork = Calloc(limit, int);
-    double *work = Calloc(lenw,  double);
+    int lenw = 4 * limit, *iwork = R_Calloc(limit, int);
+    double *work = R_Calloc(lenw,  double);
     /* done setting for Rdqags */
 
     ex[1] = sigma; ex[2] = lambda0; ex[3] = lambda1; ex[4] = lambda2;
@@ -1253,7 +1253,7 @@ struct THS_h11_p : public Worker {
       value[i] = result;
     }
   // free memory
-  Free(ex); Free(iwork); Free(work);
+  R_Free(ex); R_Free(iwork); R_Free(work);
   }
 };
 
@@ -1301,7 +1301,7 @@ struct THS_h12_p : public Worker {
     double sigma = theta[3], p = theta[4];
 
     /* set up for Rdqags */
-    double *ex = Calloc(7 + dim, double);
+    double *ex = R_Calloc(7 + dim, double);
     double a = 0., b; // = t;
     // input
     double epsabs = integrControl[0], epsrel = integrControl[1];
@@ -1311,8 +1311,8 @@ struct THS_h12_p : public Worker {
     int last, ier;  // integrate()$subdivision and integrate()$message
     int neval; // number of evaluation of integrand
     // working arrays
-    int lenw = 4 * limit, *iwork = Calloc(limit, int);
-    double *work = Calloc(lenw,  double);
+    int lenw = 4 * limit, *iwork = R_Calloc(limit, int);
+    double *work = R_Calloc(lenw,  double);
     /* done setting for Rdqags */
 
     ex[1] = sigma; ex[2] = lambda0; ex[3] = lambda1; ex[4] = lambda2;
@@ -1327,7 +1327,7 @@ struct THS_h12_p : public Worker {
       value[i] = result;
     }
   // free memory
-  Free(ex); Free(iwork); Free(work);
+  R_Free(ex); R_Free(iwork); R_Free(work);
   }
 };
 
@@ -1375,7 +1375,7 @@ struct THS_h20_p : public Worker {
     double sigma = theta[3], p = theta[4];
 
     /* set up for Rdqags */
-    double *ex = Calloc(7 + dim, double);
+    double *ex = R_Calloc(7 + dim, double);
     double a = 0., b; // = t;
     // input
     double epsabs = integrControl[0], epsrel = integrControl[1];
@@ -1385,8 +1385,8 @@ struct THS_h20_p : public Worker {
     int last, ier;  // integrate()$subdivision and integrate()$message
     int neval; // number of evaluation of integrand
     // working arrays
-    int lenw = 4 * limit, *iwork = Calloc(limit, int);
-    double *work = Calloc(lenw,  double);
+    int lenw = 4 * limit, *iwork = R_Calloc(limit, int);
+    double *work = R_Calloc(lenw,  double);
     /* done setting for Rdqags */
 
     ex[1] = sigma; ex[2] = lambda0; ex[3] = lambda1; ex[4] = lambda2;
@@ -1401,7 +1401,7 @@ struct THS_h20_p : public Worker {
       value[i] = result;
     }
   // free memory
-  Free(ex); Free(iwork); Free(work);
+  R_Free(ex); R_Free(iwork); R_Free(work);
   }
 };
 
@@ -1449,7 +1449,7 @@ struct THS_h21_p : public Worker {
     double sigma = theta[3], p = theta[4];
 
     /* set up for Rdqags */
-    double *ex = Calloc(7 + dim, double);
+    double *ex = R_Calloc(7 + dim, double);
     double a = 0., b; // = t;
     // input
     double epsabs = integrControl[0], epsrel = integrControl[1];
@@ -1459,8 +1459,8 @@ struct THS_h21_p : public Worker {
     int last, ier;  // integrate()$subdivision and integrate()$message
     int neval; // number of evaluation of integrand
     // working arrays
-    int lenw = 4 * limit, *iwork = Calloc(limit, int);
-    double *work = Calloc(lenw,  double);
+    int lenw = 4 * limit, *iwork = R_Calloc(limit, int);
+    double *work = R_Calloc(lenw,  double);
     /* done setting for Rdqags */
 
     ex[1] = sigma; ex[2] = lambda0; ex[3] = lambda1; ex[4] = lambda2;
@@ -1475,7 +1475,7 @@ struct THS_h21_p : public Worker {
       value[i] = result;
     }
   // free memory
-  Free(ex); Free(iwork); Free(work);
+  R_Free(ex); R_Free(iwork); R_Free(work);
   }
 };
 
@@ -1523,7 +1523,7 @@ struct THS_h22_p : public Worker {
     double sigma = theta[3], p = theta[4];
 
     /* set up for Rdqags */
-    double *ex = Calloc(7 + dim, double);
+    double *ex = R_Calloc(7 + dim, double);
     double a = 0., b; // = t;
     // input
     double epsabs = integrControl[0], epsrel = integrControl[1];
@@ -1533,8 +1533,8 @@ struct THS_h22_p : public Worker {
     int last, ier;  // integrate()$subdivision and integrate()$message
     int neval; // number of evaluation of integrand
     // working arrays
-    int lenw = 4 * limit, *iwork = Calloc(limit, int);
-    double *work = Calloc(lenw,  double);
+    int lenw = 4 * limit, *iwork = R_Calloc(limit, int);
+    double *work = R_Calloc(lenw,  double);
     /* done setting for Rdqags */
 
     ex[1] = sigma; ex[2] = lambda0; ex[3] = lambda1; ex[4] = lambda2;
@@ -1549,7 +1549,7 @@ struct THS_h22_p : public Worker {
       value[i] = result;
     }
   // free memory
-  Free(ex); Free(iwork); Free(work);
+  R_Free(ex); R_Free(iwork); R_Free(work);
   }
 };
 
